<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>You do not have the necessary permissions to run Stopmotion.</source>
        <translation type="obsolete">您沒有運行 Stopmotion 所必要的權限。</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>&amp;About</source>
        <translation>關於(&amp;A)</translation>
    </message>
    <message>
        <source>Main developers</source>
        <translation>主要開發人員</translation>
    </message>
    <message>
        <source>Contributors</source>
        <translation>貢獻人員</translation>
    </message>
    <message>
        <source>A&amp;uthors</source>
        <translation>作者(&amp;U)</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>翻譯</translation>
    </message>
    <message>
        <source>Czech</source>
        <translation>捷克語</translation>
    </message>
    <message>
        <source>Slovenian</source>
        <translation>斯洛維尼亞語</translation>
    </message>
    <message>
        <source>French</source>
        <translation>法語</translation>
    </message>
    <message>
        <source>Logo</source>
        <translation>圖標</translation>
    </message>
    <message>
        <source>Coordinating</source>
        <translation>協調</translation>
    </message>
    <message>
        <source>Testing</source>
        <translation>測試</translation>
    </message>
    <message>
        <source>&amp;Thanks To</source>
        <translation>感謝(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Licence Agreement</source>
        <translation>授權合約(&amp;L)</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <source>This is the Stopmotion application for creating stop motion animations.</source>
        <translation>此為用於建立定格動畫的 Stopmotion 應用程式。</translation>
    </message>
    <message>
        <source>German</source>
        <translation>德語</translation>
    </message>
    <message>
        <source>Portuguese</source>
        <translation>葡萄牙語</translation>
    </message>
    <message>
        <source>Spanish</source>
        <translation>西班牙語</translation>
    </message>
    <message>
        <source>Swedish</source>
        <translation>瑞典語</translation>
    </message>
    <message>
        <source>Traditional Chinese</source>
        <translation>傳統字漢語</translation>
    </message>
    <message>
        <source>Turkish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hebrew</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CameraHandler</name>
    <message>
        <source>Camera &amp;off</source>
        <translation type="obsolete">關閉相機(&amp;O)</translation>
    </message>
    <message>
        <source>Camera &amp;on</source>
        <translation type="obsolete">開啟相機(&amp;O)</translation>
    </message>
</context>
<context>
    <name>DeviceTab</name>
    <message>
        <source>Below you can set which device Stopmotion should use for grabbing images and displaying video.</source>
        <translation>以下您可以設定 Stopmotion 應該使用何項裝置去抓取圖像和顯示視訊。</translation>
    </message>
    <message>
        <source>You can select from the auto-detected devices below or add devices yourself. It is not recommended to use devices which is not auto-detected, but feel free to do it if you are an advanced user.</source>
        <translation>您可以從下列自動偵測的裝置選取，或是自行加入裝置。並不建議使用未被自動偵測到的裝置，但是如果您是進階使用者就儘管去做。</translation>
    </message>
    <message>
        <source>The selected device is recognized as &lt;b&gt;$VIDEODEVICE&lt;/b&gt; under Video Import.</source>
        <translation>所選的裝置被辨識為視訊匯入之下的 &lt;b&gt;$VIDEODEVICE&lt;/b&gt;。</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>加入(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>移除(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>編輯(&amp;E)</translation>
    </message>
    <message>
        <source>Video device settings</source>
        <translation>視訊裝置設定值</translation>
    </message>
    <message>
        <source>Video Device ($VIDEODEVICE): </source>
        <translation>視訊裝置 ($VIDEODEVICE)：</translation>
    </message>
    <message>
        <source>Autodetected</source>
        <translation type="obsolete">自動偵測到</translation>
    </message>
    <message>
        <source>device</source>
        <translation>裝置</translation>
    </message>
</context>
<context>
    <name>ExportTab</name>
    <message>
        <source>Active</source>
        <translation type="obsolete">當前</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>加入(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>移除(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>編輯(&amp;E)</translation>
    </message>
    <message>
        <source>Encoder settings</source>
        <translation>編碼器設定值</translation>
    </message>
    <message>
        <source>Do you want to be asked for an output file every time you choose to export?</source>
        <translation>您想要每次選擇匯出時，都向您詢問輸出檔案名稱嗎？</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <source>No</source>
        <translation>否</translation>
    </message>
    <message>
        <source>Set default output file:</source>
        <translation>設定預設輸出檔案：</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>瀏覽</translation>
    </message>
    <message>
        <source>Start encoder:</source>
        <translation>啟動編碼器：</translation>
    </message>
    <message>
        <source>Stop encoder:</source>
        <translation>停止編碼器：</translation>
    </message>
    <message>
        <source>Choose output file</source>
        <translation>選擇輸出檔案</translation>
    </message>
    <message>
        <source>&lt;p&gt;Below you can set which program/process stopmotion should use for encoding the currently active project to a video file.&lt;/p&gt;&lt;p&gt;You can use $IMAGEPATH to represent the image path (absolute path to the directory where the images can be found). You should always use &lt;b&gt;$VIDEOFILE&lt;/b&gt; to represent the output file (the videofile generated by the encoder) in the &lt;b&gt;command line&lt;/b&gt;. This is independent of how you decides to select it (select it for each export or have a default file).&lt;br&gt;&lt;/p&gt;&lt;p&gt; Example with mencoder (converting jpg to mpeg1): &lt;br&gt;mencoder mf://$IMAGEPATH/*.jpg -mf w=640:h=480:fps=12:type=jpg -ovc lavc -lavcopts vcodec=mpeg1video -oac copy -o $VIDEOFILE &lt;br&gt;</source>
        <translation type="obsolete">&lt;p&gt;以下您可以設定 stopmotion 應該使用何項程式/程序，將當前專案編碼為視訊檔案。&lt;/p&gt;&lt;p&gt;您可以使用 $IMAGEPATH 去表述圖像路徑 (可以找到圖像的目錄位置絕對路徑)。您應該固定使用&lt;b&gt;$VIDEOFILE&lt;/b&gt;在&lt;b&gt;命令列&lt;/b&gt;中去表述輸出檔案 (由編碼器產生的視訊檔案)。這跟您決定要如何選取它是無關的 (對於每個匯出都選取或是有預設檔案)。&lt;br&gt;&lt;/p&gt;&lt;p&gt;以 mencoder 為例 (轉換 jpg 到 mpeg1)：&lt;br&gt;mencoder mf://$IMAGEPATH/*.jpg -mf w=640:h=480:fps=12:type=jpg -ovc lavc -lavcopts vcodec=mpeg1video -oac copy -o $VIDEOFILE &lt;br&gt;</translation>
    </message>
    <message>
        <source>Below you can set which program/process Stopmotion should use for encoding the currently active project to a video file.</source>
        <translation>以下您可以設定 stopmotion 應該使用何項程式/程序，將當前專案編碼為視訊檔案。</translation>
    </message>
    <message>
        <source>You should always use &lt;b&gt;$IMAGEPATH&lt;/b&gt; and &lt;b&gt;$VIDEOFILE&lt;/b&gt; to represent the image path and the video file, respectively.</source>
        <translation>您應該固定使用 &lt;b&gt;$IMAGEPATH&lt;/b&gt; 和 &lt;b&gt;$VIDEOFILE&lt;/b&gt; 以分別表述圖像路徑和視訊檔案。</translation>
    </message>
    <message>
        <source>Example with mencoder (jpeg images to mpeg4 video):</source>
        <translation>以 mencoder 為例 (jpeg 圖像轉 mpeg4 視訊)：</translation>
    </message>
    <message>
        <source>You can use &lt;b&gt;$FRAMERATE&lt;/b&gt; to represent the frame rate currently in use in the project.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExternalCommand</name>
    <message>
        <source>Input to program:</source>
        <translation>輸入到程式：</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>提交</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Output from external command</source>
        <translation>從外部命令輸出</translation>
    </message>
    <message>
        <source>Result</source>
        <translation>結果</translation>
    </message>
    <message>
        <source>Failed!</source>
        <translation>失敗！</translation>
    </message>
    <message>
        <source>Successful!</source>
        <translation>成功！</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <source>Go to home directory</source>
        <translation type="obsolete">前往個人目錄</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <source>Form</source>
        <translation>表單</translation>
    </message>
</context>
<context>
    <name>FrameBar</name>
    <message>
        <source>Frame number: </source>
        <translation>圖框編號：</translation>
    </message>
</context>
<context>
    <name>FramePreferencesMenu</name>
    <message>
        <source>Add &amp;sound</source>
        <translation>加入聲音(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Remove Sound</source>
        <translation>移除聲音(&amp;R)</translation>
    </message>
    <message>
        <source>Change name</source>
        <translation>變更名稱</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>聲音：</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Add sound&lt;/h4&gt; &lt;p&gt;With this button you can &lt;em&gt;add sounds&lt;/em&gt; to the selected frame.&lt;/p&gt; &lt;p&gt;The sound will begin playing when this frame is shown and play until it is done.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;加入聲音&lt;/h4&gt;&lt;p&gt;利用這個按鈕您可以&lt;em&gt;加入聲音&lt;/em&gt;到所選的圖框。&lt;/p&gt;&lt;p&gt;此圖框顯示時，聲音將開始播放直到完成。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Remove sound&lt;/h4&gt; &lt;p&gt;With this button you can &lt;em&gt;remove&lt;/em&gt; the selected sound from this frame.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;移除聲音&lt;/h4&gt;&lt;p&gt;利用這個按鈕您可以從此圖框&lt;em&gt;移除&lt;/em&gt;所選的聲音。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Change name&lt;/h4&gt; &lt;p&gt;With this button you can change the name of the selected sound. &lt;BR&gt;The name of the sound has no other effect than making it easier work with the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;變更名稱&lt;/h4&gt;&lt;p&gt;利用這個按鈕您可以變更所選聲音的名稱。&lt;BR&gt;聲音的名稱除了讓動畫較容易製作之外，不具有其他效果。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Sounds&lt;/h4&gt; &lt;p&gt;This list shows all the sounds connected to this frame.&lt;/p&gt;&lt;p&gt;The sounds will begin playing when this frame is shown and play until they are done.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;所有聲音&lt;/h4&gt;&lt;p&gt;這份清單顯示所有連接到此圖框的聲音。&lt;/p&gt;&lt;p&gt;此圖框顯示時，聲音將開始播放直到完成。&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>FrameView</name>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Grabbing failed. This may happen if you try
to grab from an invalid device. Please check
your grabber settings in the preferences menu.</source>
        <translation>抓取失敗。如果您嘗試從無效的
裝置抓取，就有可能會發生。請檢查
您在偏好設定選單中的抓取器設定值。</translation>
    </message>
    <message>
        <source>You have to define an image grabber to use.
This can be set in the preferences menu.</source>
        <translation>您必須定義想要使用的圖像抓取器。
這可以在偏好設定選單中設定。</translation>
    </message>
    <message>
        <source>Pre poll command does not exists</source>
        <translation>輪詢前命令不存在</translation>
    </message>
    <message>
        <source>You do not have the given grabber installed on your system</source>
        <translation>您沒有在系統中安裝給定的抓取器</translation>
    </message>
    <message>
        <source>No video device selected in the preferences menu.</source>
        <translation>在偏好設定選單中沒有所選的視訊裝置。</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>&amp;New Window</source>
        <translation type="obsolete">開新視窗(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Open File</source>
        <translation type="obsolete">開啟檔案(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation type="obsolete">列印(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">關閉(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Backward</source>
        <translation type="obsolete">後退(&amp;B)</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="obsolete">前進(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Home</source>
        <translation type="obsolete">個人資料夾(&amp;H)</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation type="obsolete">加入書籤</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="obsolete">檔案(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Go</source>
        <translation type="obsolete">前往(&amp;G)</translation>
    </message>
    <message>
        <source>History</source>
        <translation type="obsolete">歷史</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">書籤</translation>
    </message>
    <message>
        <source>Backward</source>
        <translation type="obsolete">後退</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation type="obsolete">前進</translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="obsolete">個人資料夾</translation>
    </message>
</context>
<context>
    <name>ImportTab</name>
    <message>
        <source>&lt;p&gt;Below you can set which program/process stopmotion should use for grabbing images from the webcam, and displaying video.&lt;br&gt; &lt;br&gt; &lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;以下您可以設定 stopmotion 從網路攝影機抓取圖像，以及顯示視訊所應使用的程式/程序。&lt;br&gt;&lt;br&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">當前</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>加入(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>移除(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>編輯(&amp;E)</translation>
    </message>
    <message>
        <source>Import device settings</source>
        <translation>匯入裝置設定值</translation>
    </message>
    <message>
        <source>Pre-poll command</source>
        <translation>輪詢前命令</translation>
    </message>
    <message>
        <source>Start daemon</source>
        <translation>開始守護程式</translation>
    </message>
    <message>
        <source>Stop daemon</source>
        <translation>停止守護程式</translation>
    </message>
    <message>
        <source>Below you can set which program/process Stopmotion should use for grabbing images from the selected device.</source>
        <translation>以下您可以設定 Stopmotion 從所選裝置抓取圖像所應使用的程式/程序。</translation>
    </message>
    <message>
        <source>You should always use &lt;b&gt;$VIDEODEVICE&lt;/b&gt; and &lt;b&gt;$IMAGEFILE&lt;/b&gt; to represent the video device and the image file, respectively.</source>
        <translation>您應該固定使用&lt;b&gt;$VIDEODEVICE&lt;/b&gt; 和 &lt;b&gt;$IMAGEFILE&lt;/b&gt;以分別表述視訊裝置和圖像檔案。</translation>
    </message>
</context>
<context>
    <name>LanguageHandler</name>
    <message>
        <source>&amp;English</source>
        <translation type="obsolete">英語(&amp;E)</translation>
    </message>
    <message>
        <source>&lt;h4&gt;English&lt;/h4&gt; &lt;p&gt;Select this menu options to get the &lt;em&gt;English&lt;/em&gt; translation of the application.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;英語&lt;/h4&gt;&lt;p&gt;選取此功能表選項以獲得應用軟體的&lt;em&gt;英語&lt;/em&gt;翻譯。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Norwegian</source>
        <translation type="obsolete">挪威語(&amp;N)</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Norwegian&lt;/h4&gt; &lt;p&gt;Select this menu options to get the &lt;em&gt;Norwegian&lt;/em&gt; translation of the application.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;挪威語&lt;/h4&gt;&lt;p&gt;選取此功能表選項以獲得應用軟體的&lt;em&gt;挪威語&lt;/em&gt;翻譯。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>English</source>
        <comment>This should be translated to the name of the language you are translating to, in that language. Example: English = Deutsch (Deutsch is &quot;German&quot; in German)</comment>
        <translation>傳統字漢語</translation>
    </message>
    <message>
        <source>&amp;Translation</source>
        <translation>翻譯(&amp;T)</translation>
    </message>
    <message>
        <source>English</source>
        <translation type="unfinished">傳統字漢語</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Stopmotion Help Browser</source>
        <translation>Stopmotion 說明瀏覽器</translation>
    </message>
    <message>
        <source>Backward</source>
        <translation>後退</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>前進</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>MainWindowGUI</name>
    <message>
        <source>Ready to rumble ;-)</source>
        <translation>蓄勢待發 ;-)</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>新增(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>開啟(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>儲存(&amp;S)</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>另存新檔(&amp;A)</translation>
    </message>
    <message>
        <source>Add &amp;Frames</source>
        <translation type="obsolete">加入圖框(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>離開(&amp;Q)</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>檔案(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>復原(&amp;U)</translation>
    </message>
    <message>
        <source>Re&amp;do</source>
        <translation>重做(&amp;D)</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>剪下(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>複製(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>貼上(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Go to frame</source>
        <translation>前往圖框(&amp;G)</translation>
    </message>
    <message>
        <source>Prefere&amp;nces</source>
        <translation type="obsolete">偏好設定(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>編輯(&amp;E)</translation>
    </message>
    <message>
        <source>What&apos;s &amp;This</source>
        <translation>這是什麼(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>關於(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>求助(&amp;H)</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Frame preferences menu&lt;/h4&gt; &lt;p&gt;In this menu you can set preferences for the selected frame/frames, such as &lt;b&gt;subtitles&lt;/b&gt;, &lt;b&gt;sound effects&lt;/b&gt;, etc.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;圖框偏好設定選單&lt;/h4&gt;&lt;p&gt;在此選單中您可以設定用於所選圖框的偏好內容，像是&lt;b&gt;子標題&lt;/b&gt;、&lt;b&gt;聲音效果&lt;/b&gt;…等等。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Add sound</source>
        <translation type="obsolete">加入聲音</translation>
    </message>
    <message>
        <source>Remove Sound</source>
        <translation type="obsolete">移除聲音</translation>
    </message>
    <message>
        <source>Change name</source>
        <translation type="obsolete">變更名稱</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation type="obsolete">聲音：</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Go to frame menu&lt;/h4&gt; &lt;p&gt;Here you can specify a framenumber and the program will jump to the specified frame&lt;/p&gt; </source>
        <translation>&lt;h4&gt;前往圖框功能表&lt;/h4&gt;&lt;p&gt;在此您可以指定 framenumber 和程式將跳到指定的圖框&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Go to frame:</source>
        <translation>前往圖框：</translation>
    </message>
    <message>
        <source>Frame number: 0</source>
        <translation type="obsolete">圖框編號：0</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Frame number&lt;/h4&gt;&lt;p&gt;This area displays the number of the currently selected frame&lt;/p&gt;</source>
        <translation>&lt;h4&gt;圖框編號&lt;/h4&gt;&lt;p&gt;此區域顯示目前所選圖框的編號&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Unsaved changes</source>
        <translation>未儲存的變更</translation>
    </message>
    <message>
        <source>There are unsaved changes. Do you want to save?</source>
        <translation>有些未儲存的變更。您要儲存嗎？</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>是(&amp;Y)</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>否(&amp;N)</translation>
    </message>
    <message>
        <source>&lt;p&gt;This is the stopmotion application for creating stopmotion animations.&lt;/p&gt;&lt;p&gt;(c) 2005, Fredrik Berg Kjølstad and Bjørn Erik Nilsen&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;此為用來建立定格動畫的 Stopmotion 應用程式。&lt;/p&gt;&lt;p&gt;(c) 2005, Fredrik Berg Kjølstad 和 Bjørn Erik Nilsen&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation type="obsolete">儲存檔案</translation>
    </message>
    <message>
        <source>&amp;Thanks To</source>
        <translation type="obsolete">感謝(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Licence Agreement</source>
        <translation type="obsolete">授權同意書(&amp;L)</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Open&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Opens&lt;/em&gt; a Stopmotion project file.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;開啟&lt;/h4&gt;&lt;p&gt;&lt;em&gt;開啟&lt;/em&gt;一個 Stopmotion 專案檔。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Undo&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Undoes&lt;/em&gt; your last operation. You can press undo several time to undo earlier operations.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;復原&lt;/h4&gt;&lt;p&gt;&lt;em&gt;復原&lt;/em&gt;您的最後一項操作。您可以按下復原多次以回到較早的操作。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Redo&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Redoes&lt;/em&gt; your last operation. You can press redo several times to redo several operations.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;重做&lt;/h4&gt;&lt;p&gt;&lt;em&gt;重做&lt;/em&gt;您的最後一項操作。您可以按下重做多次以重做多項操作.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Cut&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Cuts&lt;/em&gt; the selected frames out of the animation and adds them to the clipboard so that you can paste them in somewhere else.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;剪下&lt;/h4&gt;&lt;p&gt;&lt;em&gt;剪下&lt;/em&gt;所選的圖框，將它們從動畫中加到剪貼簿，這樣您就可以把它們貼在其他地方。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Copy&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Copies&lt;/em&gt; the selected frames to the clipboard. You can then paste them in another place.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;複製&lt;/h4&gt;&lt;p&gt;&lt;em&gt;複製&lt;/em&gt;所選的圖框到剪貼簿。然後您可以把它們貼到另一個位置。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Paste&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Pastes&lt;/em&gt; the frames which are currently in the clipboard into the selected location.&lt;/p&gt; &lt;p&gt;You can copy/cut images from another programs and then use this option to paste them into this animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;貼上&lt;/h4&gt;&lt;p&gt;&lt;em&gt;貼上&lt;/em&gt;目前在剪貼簿中的圖框到所選的位置.&lt;/p&gt;&lt;p&gt;您可以從另外的程式複製/剪下圖像，然後利用這個選項將它們貼入這個動畫。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;What&apos;s This&lt;/h4&gt; &lt;p&gt;This will give you a WhatsThis mouse cursor which can be used to bring up helpful information like this.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;這是什麼&lt;/h4&gt;&lt;p&gt;這將提供您「這是什麼」滑鼠游標，它可以用來帶出如同此項的有用資訊。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;About&lt;/h4&gt; &lt;p&gt;This will display a small information box where you can read general information as well as the names of the developers behind this excellent piece of software.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;關於&lt;/h4&gt;&lt;p&gt;這將顯示小型資訊框，其中您可以讀到一般資訊，以及這個優秀軟體幕後的開發人員名稱。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;FrameBar&lt;/h4&gt; &lt;p&gt;In this area you can see the frames and scenes in the animations and build the animation by moving the them around.&lt;/p&gt;&lt;p&gt;You can switch to the next and the previous frame using the &lt;b&gt;arrow buttons&lt;/b&gt; or &lt;b&gt;x&lt;/b&gt; and &lt;b&gt;z&lt;/b&gt;&lt;/p&gt; </source>
        <translation>&lt;h4&gt;圖框列&lt;/h4&gt;&lt;p&gt;在此區域中您可以參看動畫中的圖框和場景，並藉由在它們周圍移動來組建動畫。&lt;/p&gt;&lt;p&gt;您可以利用&lt;b&gt;箭號按鈕&lt;/b&gt;或&lt;b&gt;x&lt;/b&gt;和&lt;b&gt;z&lt;/b&gt;&lt;/p&gt;去切換到下一張和上一張圖框。</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Tool menu&lt;/h4&gt; &lt;p&gt;This is the tool menu where most of the buttons and widgets you will need when working on stop motion animations are located.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;工具選單&lt;/h4&gt;&lt;p&gt;這是包含大部分所需按鈕和視窗元件的工具選單位置，操作定格動畫時將會需要它。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Add &amp;sound</source>
        <translation type="obsolete">加入聲音(&amp;S)</translation>
    </message>
    <message>
        <source>&lt;h4&gt;FrameView&lt;/h4&gt;&lt;p&gt; In this area you can see the selected frame. You can also play animations in this window by pressing the &lt;b&gt;Play&lt;/b&gt; button.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;圖框檢視&lt;/h4&gt;&lt;p&gt;在此區域中您可以參看所選的圖框。您也可以藉由按下&lt;b&gt;播放&lt;/b&gt;按鈕在此視窗中播放動畫。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>A&amp;uthors</source>
        <translation type="obsolete">作者(&amp;U)</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Quit&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Quits&lt;/em&gt; the program.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;離開&lt;/h4&gt;&lt;p&gt;&lt;em&gt;離開&lt;/em&gt;程式.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Go to frame&lt;/h4&gt; &lt;p&gt;This will bring up a popup-menu at the bottom where you can choose a frame you want to &lt;em&gt;go to&lt;/em&gt;.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;前往圖框&lt;/h4&gt;&lt;p&gt;這將於底部位置帶出快顯功能表，您可以選擇您想要&lt;em&gt;前往&lt;/em&gt;.&lt;/p&gt;的圖框。</translation>
    </message>
    <message>
        <source>&amp;English</source>
        <translation type="obsolete">英語(&amp;E)</translation>
    </message>
    <message>
        <source>&lt;h4&gt;English&lt;/h4&gt; &lt;p&gt;Select this menu options to get the &lt;em&gt;English&lt;/em&gt; translation of the application.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;英語&lt;/h4&gt;&lt;p&gt;選取此功能表選項以取得應用程式的&lt;em&gt;英語&lt;/em&gt;翻譯。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Norwegian</source>
        <translation type="obsolete">挪威語(&amp;N)</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Norwegian&lt;/h4&gt; &lt;p&gt;Select this menu options to get the &lt;em&gt;Norwegian&lt;/em&gt; translation of the application.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;挪威語&lt;/h4&gt;&lt;p&gt;選取此功能表選項以取得應用程式的&lt;em&gt;挪威語&lt;/em&gt;翻譯。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Languages</source>
        <translation type="obsolete">語言集(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>設定值(&amp;S)</translation>
    </message>
    <message>
        <source>Disable sound</source>
        <translation type="obsolete">停用聲音</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>視訊</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>匯出(&amp;E)</translation>
    </message>
    <message>
        <source>&lt;h4&gt;New&lt;/h4&gt; &lt;p&gt;Creates a &lt;em&gt;new&lt;/em&gt; project.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;新增&lt;/h4&gt;&lt;p&gt;建立&lt;em&gt;新的&lt;/em&gt;專案。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automatically be saved to the previously selected file.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;儲存&lt;/h4&gt;&lt;p&gt;&lt;em&gt;儲存&lt;/em&gt;目前動畫為 Stopmotion 專案檔。&lt;BR&gt;如果此專案之前已儲存，它將自動儲存到之前所選的檔案。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Save As&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;另存新檔&lt;/h4&gt;&lt;p&gt;&lt;em&gt;儲存&lt;/em&gt;目前動畫為 Stopmotion 專案檔。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Video&lt;/h4&gt; &lt;p&gt;Exports the current project as &lt;em&gt;video&lt;/em&gt;.&lt;/p&gt;You will be given a wizard to guide you.</source>
        <translation>&lt;h4&gt;視訊&lt;/h4&gt;&lt;p&gt;匯出目前專案為&lt;em&gt;視訊&lt;/em&gt;.&lt;/p&gt;將會提供指導您的精靈程式。</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Cinerella&lt;/h4&gt; &lt;p&gt;Exports the current animation as a &lt;em&gt;Cinerella&lt;/em&gt; project.&lt;/p&gt;You will be given a wizard to guide you.</source>
        <translation>&lt;h4&gt;Cinerella&lt;/h4&gt;&lt;p&gt;匯出目前動畫為&lt;em&gt;Cinerella&lt;/em&gt;專案。&lt;/p&gt;將會提供精靈程式來指導您。</translation>
    </message>
    <message>
        <source>Cinelerra</source>
        <translation>Cinelerra</translation>
    </message>
    <message>
        <source>&amp;Configure Stopmotion</source>
        <translation>配置 Stopmotion(&amp;C)</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation>開啟最近檔案(&amp;R)</translation>
    </message>
    <message>
        <source>New project</source>
        <translation>新專案</translation>
    </message>
    <message>
        <source>Open project</source>
        <translation>開啟專案</translation>
    </message>
    <message>
        <source>Save project</source>
        <translation>儲存專案</translation>
    </message>
    <message>
        <source>Save project As</source>
        <translation>專案另存為</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>離開</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>復原</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>重做</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>剪下</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>貼上</translation>
    </message>
    <message>
        <source>Go to frame</source>
        <translation>前往圖框</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Configure Stopmotion&lt;/h4&gt; &lt;p&gt;This will open a window where you can &lt;em&gt;configure&lt;/em&gt; Stopmotion with various input and output devices.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;配置 Stopmotion&lt;/h4&gt;&lt;p&gt;這將開啟一個視窗，您可以將 Stopmotion 與各種輸入和輸出裝置&lt;em&gt;配置&lt;/em&gt;。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Configure Stopmotion</source>
        <translation>配置 Stopmotion</translation>
    </message>
    <message>
        <source>What&apos;s This</source>
        <translation>這是什麼</translation>
    </message>
    <message>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Cannot find any registered encoder to be used for
video export. This can be set in the preferences
menu. Export to video will not be possible until you
have set an encoder to use. Do you want to set it now?</source>
        <translation>無法找到任何已註冊的編碼器以用於
視訊匯出。這可以在偏好選單中設定。
直到您已經設定要用的編碼器之前，
將不可能匯出為視訊。您要現在設定它嗎？</translation>
    </message>
    <message>
        <source>Export to video file</source>
        <translation>匯出至視訊檔案</translation>
    </message>
    <message>
        <source>The registered encoder is not valid. Do you want
to check your settings in the preferences menu?</source>
        <translation>已註冊的編碼器無效。您想要檢查
您在偏好設定選單中的設定值嗎？</translation>
    </message>
    <message>
        <source>Export to file</source>
        <translation>匯出至檔案</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Help&lt;/h4&gt; &lt;p&gt;This button will bring up a dialog with the Stopmotion manual&lt;/p&gt;</source>
        <translation>&lt;h4&gt;說明&lt;/h4&gt;&lt;p&gt;這個按鈕將會帶出對話框與 Stopmotion 手冊&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>求助</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Main developers&lt;/b&gt;&lt;br&gt;Fredrik Berg Kjølstad &amp;lt;fredrikbk@hotmail.com&amp;gt;&lt;br&gt;Bjørn Erik Nilsen &amp;lt;bjoern.nilsen@bjoernen.com&amp;gt;&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;&lt;b&gt;主要開發人員&lt;/b&gt;&lt;br&gt;Fredrik Berg Kjølstad &amp;lt; fredrikbk@hotmail.com &amp;gt;&lt;br&gt;Bjørn Erik Nilsen &amp;lt; bjoern.nilsen@bjoernen.com &amp;gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Stopmotion User Manual</source>
        <translation type="obsolete">Stopmotion 使用手冊</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Coordinating&lt;/b&gt;&lt;br&gt;Herman Robak &amp;lt;herman@skolelinux.no&amp;gt;&lt;br&gt;Øyvind Kolås &amp;lt;pippin@gimp.org&amp;gt;&lt;/p&gt;&lt;p&gt;&lt;b&gt;Testing&lt;/b&gt;&lt;br&gt;Tore Sinding Bekkedal &amp;lt;toresbe@ifi.uio.no&amp;gt;&lt;br&gt;Finn Arne Johansen &amp;lt;faj@bzz.no&amp;gt;&lt;br&gt;Halvor Borgen &amp;lt;halvor.borgen@hig.no&amp;gt;&lt;br&gt;Bjørn Are Hansen &amp;lt;post@bahansen.net&amp;gt;&lt;br&gt;John Steinar Bildøy &amp;lt;johnsbil@haldenfriskole.no&amp;gt;&lt;br&gt;Ole-Anders Andreassen &amp;lt;ole-anders.andreassen@sunndal.kommune.no&amp;gt;&lt;br&gt;&lt;/p&gt;&lt;p&gt;&lt;b&gt;Translation&lt;/b&gt;&lt;br&gt;George Helebrant &amp;lt;helb@skatekralovice.com&amp;gt; (Czech)&lt;br&gt;&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;&lt;b&gt;協調者&lt;/b&gt;&lt;br&gt;Herman Robak &amp;lt; herman@skolelinux.no &amp;gt;&lt;br&gt;Øyvind Kolås &amp;lt; pippin@gimp.org &amp;gt;&lt;/p&gt;&lt;p&gt;&lt;b&gt;測試者&lt;/b&gt;&lt;br&gt;Tore Sinding Bekkedal &amp;lt; toresbe@ifi.uio.no &amp;gt;&lt;br&gt;Finn Arne Johansen &amp;lt; faj@bzz.no &amp;gt;&lt;br&gt;Halvor Borgen &amp;lt; halvor.borgen@hig.no &amp;gt;&lt;br&gt;Bjørn Are Hansen &amp;lt; post@bahansen.net &amp;gt;&lt;br&gt;John Steinar Bildøy &amp;lt; johnsbil@haldenfriskole.no &amp;gt;&lt;br&gt;Ole-Anders Andreassen &amp;lt; ole-anders.andreassen@sunndal.kommune.no &amp;gt;&lt;br&gt;&lt;/p&gt;&lt;p&gt;&lt;b&gt;翻譯者&lt;/b&gt;&lt;br&gt;George Helebrant &amp;lt; helb@skatekralovice.com &amp;gt; (捷克語)&lt;br&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Frame number: </source>
        <translation>圖框編號：</translation>
    </message>
    <message>
        <source>Choose project file</source>
        <translation>選擇專案檔</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>另存新檔</translation>
    </message>
    <message>
        <source>Do&amp;n&apos;t save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ModelHandler</name>
    <message>
        <source>Choose frames to add</source>
        <translation>選擇圖框以加入</translation>
    </message>
    <message>
        <source>Removed the selected frame</source>
        <translation>移除所選圖框</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">警告</translation>
    </message>
    <message>
        <source>You do not have Gimp installed on your system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There is no active frame to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to start Gimp!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesMenu</name>
    <message>
        <source>&lt;p&gt;Below you can set which program/process stopmotion should use for grabbing images from the webcam, and displaying video.&lt;br&gt; &lt;br&gt; You can also add new programs, just make sure the image is saved with the path and filename &lt;b&gt;.stopmotion/capturedfile.png&lt;/b&gt; &lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;以下您可以設定 stopmotion 從網路攝影機抓取圖像，以及顯示視訊時應該使用的程式/程序。&lt;br&gt;&lt;br&gt;您也可以加入新的程式，只要確知圖像的儲存路徑和檔名為&lt;b&gt;.stopmotion/capturedfile.png&lt;/b&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="obsolete">加入(&amp;A)</translation>
    </message>
    <message>
        <source>Video &amp;Import</source>
        <translation>視訊匯入(&amp;I)</translation>
    </message>
    <message>
        <source>&lt;p&gt;Video Export&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;視訊匯出&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Video &amp;Export</source>
        <translation>視訊匯出(&amp;E)</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">當前</translation>
    </message>
    <message>
        <source>Command line option</source>
        <translation type="obsolete">命令列選項</translation>
    </message>
    <message>
        <source>&lt;p&gt;Below you can set which program/process stopmotion should use for grabbing images from the webcam, and displaying video.&lt;br&gt; &lt;br&gt; You can also add new programs, just make sure the command line is written with file path being &lt;b&gt;&amp;lt;DEFAULTPATH&amp;gt;&lt;/b&gt;&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;以下您可以設定 stopmotion 從網路攝影機抓取圖像，以及顯示視訊時應該使用的程式/程序。&lt;br&gt;&lt;br&gt;您也可以加入新的程式，只要確知命令列的寫入路徑為&lt;b&gt;&amp;lt; DEFAULTPATH &amp;gt;&lt;/b&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">移除(&amp;R)</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>套用</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Preferences Menu</source>
        <translation>偏好設定選單</translation>
    </message>
    <message>
        <source>Video &amp;Device</source>
        <translation>視訊裝置(&amp;D)</translation>
    </message>
</context>
<context>
    <name>QtFrontend</name>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Fatal</source>
        <translation>嚴重</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation type="obsolete">進度</translation>
    </message>
    <message>
        <source>vgrabbj VGA singleshot</source>
        <translation type="obsolete">vgrabbj VGA 單次拍照</translation>
    </message>
    <message>
        <source>vgrabbj VGA daemon</source>
        <translation>vgrabbj VGA 守護程式</translation>
    </message>
    <message>
        <source>Starts vgrabbj as a daemon. Pretty fast.</source>
        <translation>啟動 vgrabbj 為守護程式。相當快速。</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>問題</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="obsolete">是(&amp;Y)</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="obsolete">否(&amp;N)</translation>
    </message>
    <message>
        <source>The simplest setting. Fairly slow</source>
        <translation>最簡單的設定。相當慢</translation>
    </message>
    <message>
        <source>Exports from jpeg images to mpeg1 video</source>
        <translation>從 jpeg 圖像匯出到 mpeg1 視訊</translation>
    </message>
    <message>
        <source>A newer version of the preferences file with few more default
values exists. Do you want to use this one? (Your old preferences
 will be saved in ~/.stopmotion/preferences.xml.OLD)</source>
        <translation>存在較新版本的偏好設定檔與多一點
預設值。您要使用這一個嗎？(您舊的偏好設定將會
儲存在 ~/.stopmotion/preferences.xml.OLD 中)</translation>
    </message>
    <message>
        <source>Exports from jpeg images to mpeg2 video</source>
        <translation>從 jpeg 圖像匯出到 mpeg2 視訊</translation>
    </message>
    <message>
        <source>Exports from jpeg images to mpeg4 video</source>
        <translation>從 jpeg 圖像匯出到 mpeg4 視訊</translation>
    </message>
    <message>
        <source>dvgrab</source>
        <translation>dvgrab</translation>
    </message>
    <message>
        <source>Grabbing from DV-cam. (EXPERIMENTAL)</source>
        <translation type="obsolete">從 DV 攝影機抓取。(實驗性質)</translation>
    </message>
    <message>
        <source>videodog singleshot</source>
        <translation>videodog 單次拍照</translation>
    </message>
    <message>
        <source>Videodog.</source>
        <translation>Videodog。</translation>
    </message>
    <message>
        <source>Grabbing from DV-cam.</source>
        <translation>從 DV 攝影機抓取。</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting camera...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing frames from disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restoring project...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saving scenes to disk...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>vgrabbj</source>
        <translation>vgrabbj</translation>
    </message>
    <message>
        <source>uvccapture</source>
        <translation>uvcapture</translation>
    </message>
    <message>
        <source>Grabbing from V4L2 devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopmotion cannot be started; it seems like it is already running.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RunAnimationHandler</name>
    <message>
        <source>Running animation</source>
        <translation>動畫執行中</translation>
    </message>
</context>
<context>
    <name>SoundHandler</name>
    <message>
        <source>Sounds (*.ogg)</source>
        <translation>聲音 (*.ogg)</translation>
    </message>
    <message>
        <source>Sound name</source>
        <translation>聲音名稱</translation>
    </message>
    <message>
        <source>Enter the name of the sound:</source>
        <translation>輸入聲音的名稱：</translation>
    </message>
    <message>
        <source>Choose sound file</source>
        <translation>選擇聲音檔案</translation>
    </message>
</context>
<context>
    <name>ToolsMenu</name>
    <message>
        <source>&amp;Add Frames</source>
        <translation type="obsolete">加入圖框(&amp;A)</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Add Frames&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;add&lt;/em&gt; frames to the animation.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;加入圖框&lt;/h4&gt;&lt;p&gt;按一下這個按鈕以&lt;em&gt;加入&lt;/em&gt;圖框到動畫。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Remove Selection</source>
        <translation type="obsolete">移除選擇(&amp;R)</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Remove Selection&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected frames from the animation.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;移除選擇&lt;/h4&gt;&lt;p&gt;按一下這個按鈕以從動畫&lt;em&gt;移除&lt;/em&gt;所選圖框。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>New &amp;Scene</source>
        <translation type="obsolete">新增場景(&amp;S)</translation>
    </message>
    <message>
        <source>&lt;h4&gt;New Scene&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;create&lt;/em&gt; a new &lt;em&gt;scene&lt;/em&gt; to the animation.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;新增場景&lt;/h4&gt;&lt;p&gt;按一下這個按鈕以&lt;em&gt;建立&lt;/em&gt;新的動畫&lt;em&gt;場景&lt;/em&gt;。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Re&amp;move Scene</source>
        <translation type="obsolete">移除場景(&amp;M)</translation>
    </message>
    <message>
        <source>Camera &amp;on</source>
        <translation type="obsolete">開啟相機(&amp;O)</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Toggle camera on/off&lt;/h4&gt; &lt;p&gt;Click this button to toggle the camera on and off&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;切換相機開/關&lt;/h4&gt;&lt;p&gt;按一下這個按鈕以切換相機的開啟和關閉&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Capture Frame</source>
        <translation type="obsolete">擷取圖框(&amp;C)</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Capture Frame&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;capture&lt;/em&gt; a frame from the camera an put it in the animation&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h4&gt;擷取圖框&lt;/h4&gt;&lt;p&gt;按一下這個按鈕以從相機&lt;em&gt;擷取&lt;/em&gt;圖框，並將它置於動畫之中&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Number of mixes:</source>
        <translation type="obsolete">混合數量：</translation>
    </message>
    <message>
        <source>FPS chooser</source>
        <translation>FPS 選擇器</translation>
    </message>
    <message>
        <source>&lt;h4&gt;FPS chooser&lt;/h4&gt; &lt;p&gt;By changing the value in this chooser you set which speed the animation in the &lt;b&gt;FrameView&lt;/b&gt; should run at.&lt;/p&gt; &lt;p&gt;To start an animation press the &lt;b&gt;Run Animation&lt;/b&gt; button.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;FPS 選擇器&lt;/h4&gt;&lt;p&gt;藉由變更這個選擇器的值，您設定&lt;b&gt;圖框檢視&lt;/b&gt;中的動畫應該運行於何種速度。&lt;/p&gt;&lt;p&gt;要啟動動畫就按下&lt;b&gt;運行動畫&lt;/b&gt;按鈕。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Mix</source>
        <translation>混合</translation>
    </message>
    <message>
        <source>Diff</source>
        <translation>差異</translation>
    </message>
    <message>
        <source>Number of images:</source>
        <translation>圖像數量：</translation>
    </message>
    <message>
        <source>Playback</source>
        <translation>播放控制</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Add Frames (CTRL+F)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;add&lt;/em&gt; frames to the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;加入圖框 (Ctrl+F)&lt;/h4&gt;&lt;p&gt;按一下這個按鈕以&lt;em&gt;加入&lt;/em&gt;圖框到動畫。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Remove Selection (Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected frames from the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;移除選擇 (Del)&lt;/h4&gt;&lt;p&gt;按一下這個按鈕以從動畫&lt;em&gt;移除&lt;/em&gt;所選圖框。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;New Scene (CTRL+E)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;create&lt;/em&gt; a new &lt;em&gt;scene&lt;/em&gt; to the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;新增場景 (Ctrl+E)&lt;/h4&gt;&lt;p&gt;按一下這個按鈕以&lt;em&gt;建立&lt;/em&gt;新的動畫&lt;em&gt;場景&lt;/em&gt;。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Remove Scene (SHIFT+Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected scene from the animation.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;移除場景 (Shift+Del)&lt;/h4&gt;&lt;p&gt;按一下這個按鈕以從動畫&lt;em&gt;移除&lt;/em&gt;所選場景。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Toggle camera on/off (C)&lt;/h4&gt; &lt;p&gt;Click this button to toggle the camera on and off&lt;/p&gt; </source>
        <translation>&lt;h4&gt;切換相機開/關 (C)&lt;/h4&gt;&lt;p&gt;按一下這個按鈕以切換相機的開啟和關閉。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Capture Frame (Space)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;capture&lt;/em&gt; a frame from the camera an put it in the animation&lt;/p&gt; &lt;p&gt; This can also be done by pressing the &lt;b&gt;Space key&lt;/b&gt;&lt;/p&gt;</source>
        <translation>&lt;h4&gt;擷取圖框 (空格)&lt;/h4&gt;&lt;p&gt;按一下這個按鈕以從相機&lt;em&gt;擷取&lt;/em&gt;圖框，並將它置於動畫之中&lt;/p&gt;&lt;p&gt;這也可以藉由按下&lt;b&gt;空格鍵&lt;/b&gt;&lt;/p&gt;來完成</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera or if you are in playback mode: how many images to play. &lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, thereby making a smoother stop motion animation!&lt;/p&gt;</source>
        <translation>&lt;h4&gt;圖像數量&lt;/h4&gt;&lt;p&gt;藉由變更滑動桿中的值，您可以指定在動畫中從後算起有多少圖像，它們應該於相機頂部混合，或者如果您位於播放控制模式：有多少圖像將要播放。&lt;/p&gt;&lt;p&gt;藉由混合前一個圖像到相機上，您可以更容易看到下一個鏡頭與其他鏡頭是如何關聯，以便製作較平滑的定格動畫 !&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Play animation (K, P)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;播放動畫 (K, P)&lt;/h4&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Stop animation (K, P)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;停止動畫 (K, P)&lt;/h4&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Previous frame (J, Left)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;上一圖框 (J, 左)&lt;/h4&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Next frame (L, Right)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;下一圖框 (L, 右)&lt;/h4&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Previous scene (I)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;上一場景 (I)&lt;/h4&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Next scene (O)&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;下一場景 (O)&lt;/h4&gt;</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Loop animation (CTRL+L)&lt;/h4&gt; &lt;p&gt;With this button you can set whether you want the animation to play to the end, or to loop indefinitely.&lt;/p&gt;</source>
        <translation>&lt;h4&gt;循環動畫 (Ctrl+L)&lt;/h4&gt;&lt;p&gt;利用這個按鈕您可以設定是否您想要播放動畫到結束，或者是永久循環。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>通知</translation>
    </message>
    <message>
        <source>Playback only currently works when running the grabber 
as a daemon. Go to the preferences menu (CTRL+P) to switch
to running the image grabbing as a daemon.</source>
        <translation type="obsolete">目前播放控制只在以抓取器做為
守護程式執行時才有作用。前往偏好設定選單 (Ctrl+P) 
以切換圖像抓取做為守護程式執行。</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Pr sec</source>
        <translation type="obsolete">每秒</translation>
    </message>
    <message>
        <source>Pr min</source>
        <translation type="obsolete">每分鐘</translation>
    </message>
    <message>
        <source>Pr hr</source>
        <translation type="obsolete">每小時</translation>
    </message>
    <message>
        <source>Per second</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Per minute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Per hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;h4&gt;Launch Gimp&lt;/h4&gt; &lt;p&gt;Click this button to open the active frame in Gimp&lt;/p&gt; &lt;p&gt;Note that you can also drag images from the frame bar and drop them on Gimp&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playback only currently works when running the grabber 
as a daemon. Go to the preferences menu (CTRL+P) to switch 
to running the image grabbing as a daemon.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
